module.exports = defineTest({
	description: 'prioritizes entry modules over dependencies when deconflicting'
});
